==> org.eclipse.sirius.editor.diagram.source_3.0.0.201506090807.jar: org/eclipse/sirius/diagram/editor/properties/filters/style/edgestyledescription/EdgeStyleDescriptionRoutingStyleFilter.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2013 THALES GLOBAL SERVICES.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.editor.properties.filters.style.edgestyledescription;

// Start of user code specific imports

import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.sirius.diagram.description.style.BracketEdgeStyleDescription;
import org.eclipse.sirius.diagram.description.style.StylePackage;
import org.eclipse.sirius.editor.properties.filters.common.ViewpointPropertyFilter;

// End of user code specific imports

/**
 * A filter for the routingStyle property section.
 */
public class EdgeStyleDescriptionRoutingStyleFilter extends ViewpointPropertyFilter {

    /**
     * {@inheritDoc}
     */
    protected EStructuralFeature getFeature() {
        return StylePackage.eINSTANCE.getEdgeStyleDescription_RoutingStyle();
    }

    /**
     * {@inheritDoc}
     */
    protected boolean isRightInputType(Object arg0) {
        return arg0 instanceof org.eclipse.sirius.diagram.description.style.EdgeStyleDescription;
    }

    // Start of user code user methods

    /**
     * Overridden to not show routing style section for
     * {@link BracketEdgeStyleDescription}.
     * 
     * {@inheritDoc}
     */
    @Override
    public boolean select(Object arg0) {
        return !(arg0 instanceof BracketEdgeStyleDescription) && super.select(arg0);
    }

    // End of user code user methods

}

==> org.eclipse.sirius.editor.diagram.source_5.0.0.201706130938.jar: org/eclipse/sirius/diagram/editor/properties/filters/style/edgestyledescription/EdgeStyleDescriptionRoutingStyleFilter.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2013 THALES GLOBAL SERVICES.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.editor.properties.filters.style.edgestyledescription;

// Start of user code specific imports

import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.sirius.diagram.description.style.BracketEdgeStyleDescription;
import org.eclipse.sirius.diagram.description.style.StylePackage;
import org.eclipse.sirius.editor.properties.filters.common.ViewpointPropertyFilter;

// End of user code specific imports

/**
 * A filter for the routingStyle property section.
 */
public class EdgeStyleDescriptionRoutingStyleFilter extends ViewpointPropertyFilter {

    /**
     * {@inheritDoc}
     */
    protected EStructuralFeature getFeature() {
        return StylePackage.eINSTANCE.getEdgeStyleDescription_RoutingStyle();
    }

    /**
     * {@inheritDoc}
     */
    protected boolean isRightInputType(Object arg0) {
        return arg0 instanceof org.eclipse.sirius.diagram.description.style.EdgeStyleDescription;
    }

    // Start of user code user methods

    /**
     * Overridden to not show routing style section for {@link BracketEdgeStyleDescription}.
     * 
     * {@inheritDoc}
     */
    @Override
    public boolean select(Object arg0) {
        return !(arg0 instanceof BracketEdgeStyleDescription) && super.select(arg0);
    }

    // End of user code user methods

}
